ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
    MissingFileMode,
    MissingLinkCount,
    MissingOwner,
    MissingGroup,
    MissingSize,
    InvalidSize {
        token: String,
    },
    MissingMonth,
    MissingDay,
    MissingTimestamp,
    MissingName,
    EmptyQuotedName,
    InvalidEscapeSequence,
}
Possible parsing error kinds when processing ls -lpa output.

Variants



MissingFileMode

Missing file mode column.



MissingLinkCount

Missing link count column.



MissingOwner

Missing owner column.



MissingGroup

Missing group column.



MissingSize

Missing size column.



InvalidSize

Found a size column that is not a number.

Fields

token: String

The token that failed to parse.



MissingMonth

Missing timestamp month column.



MissingDay

Missing timestamp day column.



MissingTimestamp

Missing timestamp time or year column.



MissingName

Missing file or directory name.



EmptyQuotedName

Found an empty quoted name.



InvalidEscapeSequence

Found an unterminated escape sequence in a quoted name.